@@ -492,6 +492,8 @@ PyAPI_FUNC(PyObject *) PyMethod_Function(PyObject *arg0);
 PyAPI_FUNC(PyObject *) PyMethod_New(PyObject *arg0, PyObject *arg1);
 #define PyMethod_Self PyPyMethod_Self
 PyAPI_FUNC(PyObject *) PyMethod_Self(PyObject *arg0);
+#define PyModule_AddFunctions PyPyModule_AddFunctions
+PyAPI_FUNC(int) PyModule_AddFunctions(PyObject *arg0, PyMethodDef *arg1);
 #define PyModule_Check PyPyModule_Check
 PyAPI_FUNC(int) PyModule_Check(PyObject *arg0);
 #define PyModule_Create2 PyPyModule_Create2
@@ -580,6 +582,8 @@ PyAPI_FUNC(PyObject *) PyNumber_TrueDivide(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(PyObject *) PyNumber_Xor(PyObject *arg0, PyObject *arg1);
 #define PyOS_AfterFork PyPyOS_AfterFork
 PyAPI_FUNC(void) PyOS_AfterFork(void);
+#define PyOS_FSPath PyPyOS_FSPath
+PyAPI_FUNC(PyObject *) PyOS_FSPath(PyObject *arg0);
 #define PyOS_InterruptOccurred PyPyOS_InterruptOccurred
 PyAPI_FUNC(int) PyOS_InterruptOccurred(void);
 #define PyOS_double_to_string PyPyOS_double_to_string
@@ -612,8 +616,12 @@ PyAPI_FUNC(PyObject *) PyObject_Dir(PyObject *arg0);
 PyAPI_FUNC(PyObject *) PyObject_Format(PyObject *arg0, PyObject *arg1);
 #define PyObject_GenericGetAttr PyPyObject_GenericGetAttr
 PyAPI_FUNC(PyObject *) PyObject_GenericGetAttr(PyObject *arg0, PyObject *arg1);
+#define PyObject_GenericGetDict PyPyObject_GenericGetDict
+PyAPI_FUNC(PyObject *) PyObject_GenericGetDict(PyObject *arg0, void *arg1);
 #define PyObject_GenericSetAttr PyPyObject_GenericSetAttr
 PyAPI_FUNC(int) PyObject_GenericSetAttr(PyObject *arg0, PyObject *arg1, PyObject *arg2);
+#define PyObject_GenericSetDict PyPyObject_GenericSetDict
+PyAPI_FUNC(int) PyObject_GenericSetDict(PyObject *arg0, PyObject *arg1, void *arg2);
 #define PyObject_GetAttr PyPyObject_GetAttr
 PyAPI_FUNC(PyObject *) PyObject_GetAttr(PyObject *arg0, PyObject *arg1);
 #define PyObject_GetAttrString PyPyObject_GetAttrString
@@ -748,6 +756,8 @@ PyAPI_FUNC(int) PySlice_GetIndices(PyObject *arg0, Signed arg1, Signed *arg2, Si
 PyAPI_FUNC(int) PySlice_GetIndicesEx(PyObject *arg0, Signed arg1, Signed *arg2, Signed *arg3, Signed *arg4, Signed *arg5);
 #define PySlice_New PyPySlice_New
 PyAPI_FUNC(PyObject *) PySlice_New(PyObject *arg0, PyObject *arg1, PyObject *arg2);
+#define PySlice_Unpack PyPySlice_Unpack
+PyAPI_FUNC(int) PySlice_Unpack(PyObject *arg0, Signed *arg1, Signed *arg2, Signed *arg3);
 #define PyStaticMethod_New PyPyStaticMethod_New
 PyAPI_FUNC(PyObject *) PyStaticMethod_New(PyObject *arg0);
 #define PySys_GetObject PyPySys_GetObject
@@ -902,6 +912,8 @@ PyAPI_FUNC(PyObject *) PyUnicode_InternFromString(const char *arg0);
 PyAPI_FUNC(void) PyUnicode_InternInPlace(PyObject **arg0);
 #define PyUnicode_Join PyPyUnicode_Join
 PyAPI_FUNC(PyObject *) PyUnicode_Join(PyObject *arg0, PyObject *arg1);
+#define PyUnicode_New PyPyUnicode_New
+PyAPI_FUNC(PyObject *) PyUnicode_New(Py_ssize_t arg0, Py_UCS4 arg1);
 #define PyUnicode_Replace PyPyUnicode_Replace
 PyAPI_FUNC(PyObject *) PyUnicode_Replace(PyObject *arg0, PyObject *arg1, PyObject *arg2, Signed arg3);
 #define PyUnicode_Resize PyPyUnicode_Resize
@@ -1052,6 +1064,12 @@ PyAPI_FUNC(void) _PyPyGC_AddMemoryPressure(Signed arg0);
 extern void _PyPy_Free(void *arg0);
 #define _PyPy_Malloc _PyPyPy_Malloc
 extern void * _PyPy_Malloc(Signed arg0);
+#define _PySet_Next _PyPySet_Next
+PyAPI_FUNC(int) _PySet_Next(PyObject *arg0, Signed *arg1, PyObject **arg2);
+#define _PySet_NextEntry _PyPySet_NextEntry
+PyAPI_FUNC(int) _PySet_NextEntry(PyObject *arg0, Signed *arg1, PyObject **arg2, Signed *arg3);
+#define _PyThreadState_UncheckedGet _PyPyThreadState_UncheckedGet
+PyAPI_FUNC(PyThreadState *) _PyThreadState_UncheckedGet(void);
 #define _PyTime_FromTime _PyPyTime_FromTime
 PyAPI_FUNC(PyObject *) _PyTime_FromTime(int arg0, int arg1, int arg2, int arg3, PyObject *arg4, PyTypeObject *arg5);
 #define _PyTuple_Resize _PyPyTuple_Resize
@@ -1066,6 +1084,12 @@ PyAPI_FUNC(int) _PyUnicode_Ready(PyObject * arg0);
 PyAPI_FUNC(Signed) _Py_HashDouble(double arg0);
 #define _Py_HashPointer _PyPy_HashPointer
 PyAPI_FUNC(Signed) _Py_HashPointer(void *arg0);
+#define _Py_IsFinalizing _PyPy_IsFinalizing
+PyAPI_FUNC(int) _Py_IsFinalizing(void);
+#define _Py_strhex _PyPy_strhex
+PyAPI_FUNC(PyObject *) _Py_strhex(char const * arg0, Py_ssize_t arg1);
+#define _Py_strhex_bytes _PyPy_strhex_bytes
+PyAPI_FUNC(PyObject *) _Py_strhex_bytes(char const * arg0, Py_ssize_t arg1);
 #define PyExc_MemoryError PyPyExc_MemoryError
 PyAPI_DATA(PyObject*) PyExc_MemoryError;
 #define PyByteArray_Type PyPyByteArray_Type
